package com.ruoyi.brewery.mapper;

import java.util.List;
import com.ruoyi.brewery.domain.WyBreweryTagPrintTemplate;

/**
 * 品牌方标签套打模板Mapper接口
 * 
 * @author ruoyi
 * @date 2025-02-15
 */
public interface WyBreweryTagPrintTemplateMapper 
{
    /**
     * 查询品牌方标签套打模板
     * 
     * @param id 品牌方标签套打模板主键
     * @return 品牌方标签套打模板
     */
    public WyBreweryTagPrintTemplate selectWyBreweryTagPrintTemplateById(Long id);

    /**
     * 查询品牌方标签套打模板列表
     * 
     * @param wyBreweryTagPrintTemplate 品牌方标签套打模板
     * @return 品牌方标签套打模板集合
     */
    public List<WyBreweryTagPrintTemplate> selectWyBreweryTagPrintTemplateList(WyBreweryTagPrintTemplate wyBreweryTagPrintTemplate);

    /**
     * 新增品牌方标签套打模板
     * 
     * @param wyBreweryTagPrintTemplate 品牌方标签套打模板
     * @return 结果
     */
    public int insertWyBreweryTagPrintTemplate(WyBreweryTagPrintTemplate wyBreweryTagPrintTemplate);

    /**
     * 修改品牌方标签套打模板
     * 
     * @param wyBreweryTagPrintTemplate 品牌方标签套打模板
     * @return 结果
     */
    public int updateWyBreweryTagPrintTemplate(WyBreweryTagPrintTemplate wyBreweryTagPrintTemplate);

    /**
     * 删除品牌方标签套打模板
     * 
     * @param id 品牌方标签套打模板主键
     * @return 结果
     */
    public int deleteWyBreweryTagPrintTemplateById(Long id);

    /**
     * 批量删除品牌方标签套打模板
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteWyBreweryTagPrintTemplateByIds(Long[] ids);
}
